@@ -50,7 +50,7 @@ inf: Final = float("inf")
 neg_inf: Final = float("-inf")
 
 
-class Interval(Phantom[float], bound=RealLike, abstract=True):
+class Interval(Phantom[RealLike], bound=RealLike, abstract=True):
     """
     Base class for all interval types, providing the following class arguments:
 
